fn root_transform_for_fragments(
scroll_tree: &ScrollTree,
fragments: &[Fragment],
) -> Option<FastLayoutTransform>Expand description
Calculate the cumulative transform from the root scroll node for fragments.
fn root_transform_for_fragments(
scroll_tree: &ScrollTree,
fragments: &[Fragment],
) -> Option<FastLayoutTransform>Calculate the cumulative transform from the root scroll node for fragments.